==> qtjambi-qml-debuginfo-macos-6.7.0.jar: sources/QtJambiQml/QQmlPropertyMap_shell.h <==
#ifndef QQMLPROPERTYMAP_SHELL_H
#define QQMLPROPERTYMAP_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQml/qqmlpropertymap.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QQmlPropertyMap_shell : public QQmlPropertyMap, public QtJambiShellInterface
{
public:
    QQmlPropertyMap_shell(QObject* parent0 = nullptr);
    ~QQmlPropertyMap_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QVariant updateValue(const QString& key0, const QVariant& input1) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlPropertyMap_access : public QQmlPropertyMap
{
    jobject __qt_updateValue_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring key0, jobject input1);
};

#endif // QQMLPROPERTYMAP_SHELL_H

==> qtjambi-qml-debuginfo-macos-6.8.0.jar: sources/QtJambiQml/QQmlPropertyMap_shell.h <==
#ifndef QQMLPROPERTYMAP_SHELL_H
#define QQMLPROPERTYMAP_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtQml/qqmlpropertymap.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QHash>
#include <QtCore/QList>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qvariant.h>
#include <QtJambi/RegistryAPI>


class QQmlPropertyMap_shell : public QQmlPropertyMap, public QtJambiShellInterface
{
public:
    QQmlPropertyMap_shell(QObject* parent0 = nullptr);
    ~QQmlPropertyMap_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QQmlPropertyMap_mshell;
    friend class QQmlPropertyMap_oshell;
};


class QQmlPropertyMap_mshell : public QQmlPropertyMap_shell
{
public:
    using QQmlPropertyMap_shell::QQmlPropertyMap_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QQmlPropertyMap_oshell : public QQmlPropertyMap_mshell
{
public:
    using QQmlPropertyMap_mshell::QQmlPropertyMap_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    QVariant updateValue(const QString& key0, const QVariant& input1) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QQmlPropertyMap_access : public QQmlPropertyMap
{
    jobject __qt_updateValue_cref_QString_cref_QVariant(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jstring key0, jobject input1);
};

#endif // QQMLPROPERTYMAP_SHELL_H
